@@ -1,20 +1,9 @@
 /*
-  Copyright 2010 BetterInbox <contact@betterinbox.com>
-      Author: Christophe Laveault <christophe@betterinbox.com>
-              Gregory Schlomoff <gregory.schlomoff@gmail.com>
+  SPDX-FileCopyrightText: 2010 BetterInbox <contact@betterinbox.com>
+  SPDX-FileContributor: Christophe Laveault <christophe@betterinbox.com>
+  SPDX-FileContributor: Gregory Schlomoff <gregory.schlomoff@gmail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "smtptest.h"
@@ -167,7 +156,7 @@ void SmtpTest::testLoginJob()
     session.setCustomHostname(QStringLiteral("127.0.0.1"));
     session.openAndWait();
 
-    KSmtp::LoginJob *login = new KSmtp::LoginJob(&session);
+    auto *login = new KSmtp::LoginJob(&session);
     login->setPreferedAuthMode(mode);
     login->setUserName(QStringLiteral("login"));
     login->setPassword(QStringLiteral("password"));
@@ -237,7 +226,7 @@ void SmtpTest::testSendJob()
     session.setCustomHostname(QStringLiteral("127.0.0.1"));
     session.openAndWait();
 
-    KSmtp::SendJob *send = new KSmtp::SendJob(&session);
+    auto *send = new KSmtp::SendJob(&session);
     send->setData("From: foo@bar.com\r\nTo: bar@foo.com\r\nHello world.\r\n.\r\n.\r\n..\r\n.Foo\r\nEnd");
     send->setFrom(QStringLiteral("foo@bar.com"));
     send->setTo({QStringLiteral("bar@foo.com")});
